==> vue-components-1.5.40.tgz: package/lib/form/src/shared/ValidationMessage.vue.rd.js <==
import { pt as i } from "@regiondev/vue-utils";
import { defineComponent as v, toRefs as N, computed as l, openBlock as a, createElementBlock as c, createVNode as b, Transition as g, withCtx as C, unref as n, normalizeClass as m, createElementVNode as o, toDisplayString as d, createCommentVNode as R } from "vue";
import { debouncedRef as u } from "@vueuse/core";
import { InputState as e } from "./enums/state.enum.rd.js";
const S = { class: "relative pb-10 mt-0.5 overflow-hidden input-animation" }, E = { class: "mt-0.5 mb-0 pb-0 ml-1 truncate color-inherit" }, w = {
  key: 1,
  class: "absolute flex items-center top-0"
}, O = /* @__PURE__ */ o("span", { class: "i-heroicons-solid:information-circle color-inherit p-3 text-lg" }, null, -1), k = { class: "mt-0.5 mb-0 pb-0 ml-1 truncate color-inherit" }, B = /* @__PURE__ */ v({
  __name: "ValidationMessage",
  props: {
    state: i.oneOf(["success", "warning", "error", "none"]).def("none"),
    hint: i.string,
    infoText: i.string
  },
  setup(s) {
    const p = s, { state: f, hint: h } = N(p), t = u(f, 100), r = u(h, 100), _ = l(() => ({
      "text-red-500": t.value == e.ERROR,
      "text-yellow-500": t.value == e.WARNING,
      "text-green-500": t.value == e.SUCCESS,
      "text-blue-500": t.value == e.NONE
    })), x = l(() => {
      switch (t.value) {
        case e.ERROR:
          return "i-heroicons-solid:exclamation-circle";
        case e.SUCCESS:
          return "i-heroicons-solid:check-circle";
        case e.WARNING:
          return "i-heroicons-solid:exclamation";
        case e.NONE:
          return "i-heroicons-solid:information-circle";
      }
    });
    return (y, I) => (a(), c("div", S, [
      b(g, {
        "enter-active-class": "animate__animated animate__fadeInDown",
        "leave-active-class": "animate__animated animate__fadeOutUp"
      }, {
        default: C(() => [
          n(r) ? (a(), c("span", {
            key: 0,
            class: m([n(_), "absolute flex items-center top-0"])
          }, [
            o("span", {
              class: m([n(x), "color-inherit p-3 text-lg"])
            }, null, 2),
            o("p", E, d(n(r)), 1)
          ], 2)) : s.infoText ? (a(), c("span", w, [
            O,
            o("p", k, d(s.infoText), 1)
          ])) : R("", !0)
        ]),
        _: 1
      })
    ]));
  }
});
export {
  B as default
};

==> vue-components-1.5.43.tgz: package/lib/form/src/shared/ValidationMessage.vue.rd.js <==
import { pt as i } from "@regiondev/vue-utils";
import { defineComponent as v, toRefs as N, computed as l, openBlock as a, createElementBlock as c, createVNode as g, Transition as C, withCtx as R, unref as n, normalizeClass as m, createElementVNode as o, toDisplayString as d, createCommentVNode as b } from "vue";
import { debouncedRef as u } from "@vueuse/core";
import { InputState as e } from "./enums/state.enum.rd.js";
const S = { class: "relative pb-10 mt-0.5 overflow-hidden input-animation" }, E = { class: "mt-0.5 mb-0 pb-0 ml-1 truncate color-inherit" }, w = {
  key: 1,
  class: "absolute flex items-center top-0"
}, O = /* @__PURE__ */ o("span", { class: "i-heroicons-solid:information-circle color-inherit p-3 text-lg" }, null, -1), k = { class: "mt-0.5 mb-0 pb-0 ml-1 truncate color-inherit" }, B = /* @__PURE__ */ v({
  __name: "ValidationMessage",
  props: {
    state: i.oneOf(["success", "warning", "error", "none"]).def("none"),
    hint: i.string,
    infoText: i.string
  },
  setup(s) {
    const p = s, { state: f, hint: h } = N(p), t = u(f, 100), r = u(h, 100), _ = l(() => ({
      "!text-red-500": t.value == e.ERROR,
      "!text-yellow-500": t.value == e.WARNING,
      "!text-green-500": t.value == e.SUCCESS,
      "text-primary-500": t.value == e.NONE
    })), x = l(() => {
      switch (t.value) {
        case e.ERROR:
          return "i-heroicons-solid:exclamation-circle";
        case e.SUCCESS:
          return "i-heroicons-solid:check-circle";
        case e.WARNING:
          return "i-heroicons-solid:exclamation";
        case e.NONE:
          return "i-heroicons-solid:information-circle";
      }
    });
    return (y, I) => (a(), c("div", S, [
      g(C, {
        "enter-active-class": "animate__animated animate__fadeInDown",
        "leave-active-class": "animate__animated animate__fadeOutUp"
      }, {
        default: R(() => [
          n(r) ? (a(), c("span", {
            key: 0,
            class: m([n(_), "absolute flex items-center top-0"])
          }, [
            o("span", {
              class: m([n(x), "color-inherit p-3 text-lg"])
            }, null, 2),
            o("p", E, d(n(r)), 1)
          ], 2)) : s.infoText ? (a(), c("span", w, [
            O,
            o("p", k, d(s.infoText), 1)
          ])) : b("", !0)
        ]),
        _: 1
      })
    ]));
  }
});
export {
  B as default
};
